@@ -4,7 +4,7 @@ build_time_vars = {'ABIFLAGS': '',
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
- 'ARFLAGS': 'rc',
+ 'ARFLAGS': 'rcs',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
@@ -39,6 +39,7 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                       '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
                       '-Wl,-R/usr/X11R7/lib',
+ 'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--enable-shared' '--with-system-ffi' '--with-threads' "
                 "'--without-ensurepip' '--without-pymalloc' "
                 "'--prefix=/usr/pkg' '--build=armv7--netbsdelf-eabihf' "
@@ -54,8 +55,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.6',
  'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.7/coverage.info',
- 'COVERAGE_REPORT': '/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.7/lcov-report',
+ 'COVERAGE_INFO': '/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.8/coverage.info',
+ 'COVERAGE_REPORT': '/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.8/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
@@ -507,6 +508,7 @@ build_time_vars = {'ABIFLAGS': '',
             '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib -L/usr/lib -Wl,-R/usr/lib '
             '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
             '-Wl,-R/usr/X11R7/lib',
+ 'LDFLAGS_NODIST': '',
  'LDLAST': '',
  'LDLIBRARY': 'libpython3.6.so',
  'LDLIBRARYDIR': '',
@@ -619,6 +621,10 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Wno-unused-parameter -Wno-missing-field-initializers -I. '
                    '-I./Include -I/usr/include -I/usr/pkg/include '
                    '-I/usr/include -I/usr/pkg/include -fPIC -DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-L. -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+                    '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
+                    '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+                    '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
                 '-I/usr/include -I/usr/pkg/include',
  'PY_FORMAT_SIZE_T': '"z"',
@@ -626,15 +632,15 @@ build_time_vars = {'ABIFLAGS': '',
                '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
                '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
                '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+ 'PY_LDFLAGS_NODIST': '',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
- 'RANLIB': 'ranlib',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.7',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.8',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
@@ -675,10 +681,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.7 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.8 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.7 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.8 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'THREADOBJ': 'Python/thread.o',
@@ -703,8 +709,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.7',
- 'abs_srcdir': '/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.7',
+ 'abs_builddir': '/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.8',
+ 'abs_srcdir': '/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.8',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
